# Simple word embedding models

[![PyPI version](https://img.shields.io/pypi/v/pytorch-swem)](https://pypi.org/project/pytorch-swem/)
[![PyPI - License](https://img.shields.io/pypi/l/pytorch-swem)](https://github.com/schoennenbeck/swem/blob/main/LICENSE)
[![Coverage Status](https://coveralls.io/repos/github/schoennenbeck/swem/badge.svg)](https://coveralls.io/github/schoennenbeck/swem)

A pytorch implementation of the Simple Word Embedding Model from the paper [Baselines need more love](https://arxiv.org/abs/1808.09843) and some additional models and utilities.

## Installation

### From pypi

To install this package from pypi simply run

```
pip install pytorch-swem
```

### From source

To install from source clone this repository and install via pip:

```
git clone https://github.com/schoennenbeck/swem.git
cd swem
pip install .
```

## Docs

The [documentation](https://pytorch-swem.readthedocs.io/) is currently under development.
